@@ -2,8 +2,8 @@ import tensorflow as tf
 from absl import logging
 
 from tf_transformers.core.legacy_model import LegacyModel
-from tf_transformers.layers import (MLMLayer, OnDeviceEmbedding,
-                             SimplePositionEmbedding)
+from tf_transformers.layers import MLMLayer, OnDeviceEmbedding, SimplePositionEmbedding
+
 
 class LegacyLayer(tf.keras.layers.Layer):
     """
@@ -56,7 +56,8 @@ class LegacyLayer(tf.keras.layers.Layer):
         if self.is_training:
             if self.pipeline_mode is not None:
                 raise ValueError(
-                    "When `is_training` is True, `pipeline_mode` should be None. But rather got `pipeline_mode` as {}".format(
+                    "When `is_training` is True, `pipeline_mode` \
+                        should be None. But rather got `pipeline_mode` as {}".format(
                         self.pipeline_mode
                     )
                 )
@@ -65,7 +66,8 @@ class LegacyLayer(tf.keras.layers.Layer):
         if self.is_training is False:
             if self.pipeline_mode is None:
                 logging.info(
-                    "We are overwriding `is_training` is False to `is_training` to True with `use_dropout` is False, no effects on your inference pipeline"
+                    "We are overwriding `is_training` is False to \
+                        `is_training` to True with `use_dropout` is False, no effects on your inference pipeline"
                 )
                 self.is_training = True
                 self.use_dropout = False
@@ -102,7 +104,7 @@ class LegacyLayer(tf.keras.layers.Layer):
                             )
                         )
 
-    def get_embedding_layers(self, embedding_size = None):
+    def get_embedding_layers(self, embedding_size=None):
         if embedding_size is None:
             embedding_size = self.embedding_size
         # Word Embedding Layer
@@ -133,6 +135,7 @@ class LegacyLayer(tf.keras.layers.Layer):
         return self._embedding_layer, self._type_embeddings, self._position_embedding_layer
 
     def get_call_method(self):
+
         # Training Pipeline
         if self.is_training:
             # Decoder Mode Training
@@ -163,7 +166,7 @@ class LegacyLayer(tf.keras.layers.Layer):
             elif self.cross_attention_inside_encoder:
                 # we want predict mode to be ready only when
                 # pipeline_mode == 'auto-regressive
-                if self.pipeline_mode == 'auto-regressive':
+                if self.pipeline_mode == "auto-regressive":
                     method = self.call_cross_attention_encoder_predict
                 else:
                     self.use_dropout = False
@@ -252,7 +255,7 @@ class LegacyLayer(tf.keras.layers.Layer):
             # for k, v in inputs.items():
             #     logging.info("{} ---> {}".format(k, v))
             model = LegacyModel(inputs=inputs, outputs=layer_outputs, name=self.name)
-            model.model_config = {'decoder': self._config_dict}
+            model.model_config = {"decoder": self._config_dict}
             return model
 
         # Encoder
