@@ -185,6 +185,7 @@ class TransformermT5(LegacyLayer):
                     use_dropout=self.use_dropout,
                     name="cross_attention",
                     use_bias=self._use_bias,
+                    is_cross_attention=True,  # hard code
                 )
 
                 self._cross_attention_output_dense = dense_einsum.DenseEinsum(
@@ -271,7 +272,7 @@ class TransformermT5(LegacyLayer):
             "bias_constraint": tf.keras.constraints.serialize(self._bias_constraint),
             "is_training": self.is_training,
         }
-        base_config = super(TransformerT5, self).get_config()
+        base_config = super(TransformermT5, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
     def call_training(self, inputs, position_bias=None, cache_key=None, cache_value=None):
