@@ -1,8 +1,13 @@
-from tf_transformers.utils import get_config, validate_model_name
-from tf_transformers.models import BERTEncoder
 import tensorflow as tf
+from absl import logging
+
+from tf_transformers.models import BERTEncoder
+from tf_transformers.utils import get_config, validate_model_name
+
+logging.set_verbosity("INFO")
 allowed_model_names = ["bert_base_cased", "bert_base_uncased", "bert_large_cased", "bert_large_uncased"]
 
+
 def modelWrapper(model_name, **kwargs):
     """Wrapper for Model
 
@@ -15,10 +20,22 @@ def modelWrapper(model_name, **kwargs):
 
     name = "bert"
 
-    model_name = model_name.replace('-', '_') # replace - with _
+    model_name = model_name.replace("-", "_")  # replace - with _
     validate_model_name(model_name, allowed_model_names)
     config = get_config("tf_transformers.models.model_configs.bert", model_name)
 
+    config_kwargs = []
+    for _kwarg in kwargs:
+        if _kwarg in config:
+            config[_kwarg] = kwargs[_kwarg]
+            logging.info("Overwride {} with {}".format(_kwarg, kwargs[_kwarg]))
+            config_kwargs.append(_kwarg)
+
+    # If it is in kwargs, Keras Layer will throw error
+    if config_kwargs:
+        for _kwarg in config_kwargs:
+            del kwargs[_kwarg]
+
     if "is_training" not in kwargs:
         kwargs["is_training"] = False
         kwargs["pipeline_mode"] = None
@@ -37,4 +54,3 @@ def modelWrapper(model_name, **kwargs):
     if checkpoint_dir:
         model.load_checkpoint(checkpoint_dir)
     return model_layer, model, config
-
